// Copyright 2023-2024 Gentoo Authors
// Distributed under the terms of the GNU General Public License v2

namespace Gdmt.Govendor

module Private =
    open System
    open System.IO

    open SimpleLog.SimpleLog

    open Gdmt.Shared

    let CreateArchive (inputDirectory: string) (outputFile: string) : unit =
        if File.Exists outputFile then
            File.Delete outputFile

        let numThreads = Environment.ProcessorCount
        let numSafeThreads = if numThreads > 2 then numThreads - 2 else 1

        let args =
            [ "tar"; "--auto-compress"; "--create"; "--file"; outputFile; inputDirectory ]

        let env = [ ("XZ_OPT", $"-T{numSafeThreads}") ]

        LogMessage Debug $"Creating archive from:  {inputDirectory}"
        LogMessage Debug $"Creating archive file:  {outputFile}"

        ExecProcess(args, env).Run().Check()
